import json

from fastapi import APIRouter, HTTPException, status

from nnext.server.lib.auth.prisma import (
    encryptPassword,
    signJWT,
    validatePassword,
)
from nnext.server.lib.models.auth import SignIn, SignInOut, SignUp
from nnext.server.lib.prisma import prisma

router = APIRouter()


@router.post("/auth/sign-in")
async def sign_in(signIn: SignIn):
    user = prisma.user.find_first(
        where={
            "email": signIn.email,
        },
        include={"profile": True},
    )
    if user:
        validated = validatePassword(signIn.password, user.password)
        del user.password

        if validated:
            token = signJWT(user.id)
            return {"success": True, "data": SignInOut(token=token, user=user)}

        raise HTTPException(
            status_code=status.HTTP_401_UNAUTHORIZED,
            detail="Invalid credentials",
        )
    else:
        raise HTTPException(
            status_code=status.HTTP_401_UNAUTHORIZED,
            detail="Invalid credentials",
        )


@router.post("/auth/sign-up")
async def sign_up(body: SignUp):
    encryptPassword(body.password)
    user = prisma.user.create(
        {
            "email": body.email,
            "password": encryptPassword(body.password),
            "name": body.name,
        }
    )
    prisma.profile.create({"userId": user.id, "metadata": json.dumps(body.metadata)})

    if user:
        return {"success": True, "data": user}

    raise HTTPException(
        status_code=status.HTTP_400_BAD_REQUEST,
        detail="Invalid credentials",
    )
